@@ -83,12 +83,10 @@ class VNumber(Validator):
         if type(value) not in (int, float):
             msg = E("(int, float)型のいずれかである必要があります", value)
             raise TypeError(msg)
-        mini = self.minimum
-        if mini is not None and value < mini:
+        if (mini := self.minimum) is not None and value < mini:
             msg = E(f"{mini}より小さい値を設定することはできません", value)
             raise ValueError(msg)
-        maxi = self.maximum
-        if maxi is not None and value > maxi:
+        if (maxi := self.maximum) is not None and value > maxi:
             msg = E(f"{maxi}より大きい値を設定することはできません", value)
             raise ValueError(msg)
         return value
@@ -146,14 +144,12 @@ class VPath(Validator):
         if not isinstance(value, Path):
             msg = E("Path型である必要があります", value)
             raise TypeError(msg)
-        sf = self.suffix
-        if sf:
+        if sf := self.suffix:
             if value.suffix not in sf:
                 msg = E(f"拡張子が{sf[0]}である必要があります" if len(sf) == 1 else f"拡張子が{sf}のいずれかである必要があります", value)
                 raise ValueError(msg)
         if value.exists():
-            pt = self.path_type
-            if pt is not None and not pt(value):
+            if (pt := self.path_type) is not None and not pt(value):
                 msg = E(f"{pt}がTrueを返すパスである必要があります", value)
                 raise FileExistsError(msg)
         else:
@@ -187,16 +183,13 @@ class VString(Validator):
             msg = E("str型である必要があります", value)
             raise TypeError(msg)
         lv = len(value)
-        mini = self.minimum
-        if mini is not None and lv < mini:
+        if (mini := self.minimum) is not None and lv < mini:
             msg = E(f"{mini}文字以上である必要があります", value)
             raise ValueError(msg)
-        maxi = self.maximum
-        if maxi is not None and lv > maxi:
+        if (maxi := self.maximum) is not None and lv > maxi:
             msg = E(f"{maxi}文字以下である必要があります", value)
             raise ValueError(msg)
-        checker = self.checker
-        if checker is not None and not checker(value):
+        if (checker := self.checker) is not None and not checker(value):
             msg = E(f"指定した形式に対応している必要があります。{repr(checker)}", value)
             raise ValueError(msg)
         return value
@@ -270,12 +263,10 @@ class VDict(VContainer):
         KEYS = set(self.TEMPLATE.keys())
         VKEYS = set(value.keys())
         if KEYS ^ VKEYS:
-            unnecessary_keys = VKEYS - KEYS
-            if unnecessary_keys:
+            if unnecessary_keys := VKEYS - KEYS:
                 msg = E(f"以下のキーを設定することはできません。({unnecessary_keys})", value)
                 raise ValueError(msg)
-            missing_key = KEYS - VKEYS
-            if not self.allow_missing_key and missing_key:
+            if not self.allow_missing_key and (missing_key := KEYS - VKEYS):
                 msg = E(f"以下のキーを設定する必要があります。({missing_key})", value)
                 raise ValueError(msg)
         for k, v in value.items():
@@ -335,12 +326,10 @@ class VList(VContainer):
         if type(self.TEMPLATE) is list:
             return self._validate_of_structure(value)
         lv = len(value)
-        mini = self.minimum
-        if mini is not None and lv < mini:
+        if (mini := self.minimum) is not None and lv < mini:
             msg = E(f"あと{mini-lv}個設定する必要があります", value)
             raise ValueError(msg)
-        maxi = self.maximum
-        if maxi is not None and lv > maxi:
+        if (maxi := self.maximum) is not None and lv > maxi:
             msg = E(f"あと{lv-maxi}個減らす必要があります", value)
             raise ValueError(msg)
         if isinstance(self.TEMPLATE, Validator):
@@ -350,8 +339,7 @@ class VList(VContainer):
 
     def _validate_by_type(self, value) -> list:
         E = self.ERRMSG
-        is_type = inspect.isclass(self.TEMPLATE)
-        vtype = self.TEMPLATE if is_type else type(self.TEMPLATE)
+        vtype = self.TEMPLATE if (is_type := inspect.isclass(self.TEMPLATE)) else type(self.TEMPLATE)
         for i, v in enumerate(value):
             msg = E(f"インデックス{i}は{vtype.__name__}型である必要があります", v, False)
             if type(v) is bool:
@@ -385,8 +373,7 @@ class VList(VContainer):
 
     def _validate_of_structure(self, value) -> list:
         E = self.ERRMSG
-        diff_len = len(value) - len(self.TEMPLATE)
-        if diff_len > 0:
+        if (diff_len := len(value) - len(self.TEMPLATE)) > 0:
             msg = E(f"あと{diff_len}個減らす必要があります", value)
             raise ValueError(msg)
         if diff_len < 0:
@@ -407,8 +394,7 @@ class VList(VContainer):
                     msg = E(f"インデックス{i}は不正な値です", v, False)
                     raise etype(msg)
             else:
-                is_type = inspect.isclass(validator)
-                vtype = validator if is_type else type(validator)
+                vtype = validator if (is_type := inspect.isclass(validator)) else type(validator)
                 msg = E(f"インデックス{i}は{vtype.__name__}型である必要があります", v, False)
                 if type(v) is bool:
                     if vtype is not bool:
@@ -463,12 +449,10 @@ class VTuple(VContainer):
         if type(self.TEMPLATE) is tuple:
             return self._validate_of_structure(value)
         lv = len(value)
-        mini = self.minimum
-        if mini is not None and lv < mini:
+        if (mini := self.minimum) is not None and lv < mini:
             msg = E(f"あと{mini-lv}個設定する必要があります", value)
             raise ValueError(msg)
-        maxi = self.maximum
-        if maxi is not None and lv > maxi:
+        if (maxi := self.maximum) is not None and lv > maxi:
             msg = E(f"あと{lv-maxi}個減らす必要があります", value)
             raise ValueError(msg)
         if isinstance(self.TEMPLATE, Validator):
@@ -478,8 +462,7 @@ class VTuple(VContainer):
 
     def _validate_by_type(self, value) -> tuple:
         E = self.ERRMSG
-        is_type = inspect.isclass(self.TEMPLATE)
-        vtype = self.TEMPLATE if inspect.isclass(self.TEMPLATE) else type(self.TEMPLATE)
+        vtype = self.TEMPLATE if (is_type := inspect.isclass(self.TEMPLATE)) else type(self.TEMPLATE)
         for i, v in enumerate(value):
             msg = E(f"インデックス{i}は{vtype.__name__}型である必要があります", v, False)
             if type(v) is bool:
@@ -525,8 +508,7 @@ class VTuple(VContainer):
     def _validate_of_structure(self, value) -> tuple:
         E = self.ERRMSG
         TMP = cast(tuple, self.TEMPLATE)
-        diff_len = len(value) - len(TMP)
-        if diff_len > 0:
+        if (diff_len := len(value) - len(TMP)) > 0:
             msg = E(f"あと{diff_len}個減らす必要があります", value)
             raise ValueError(msg)
         if diff_len < 0:
@@ -546,8 +528,7 @@ class VTuple(VContainer):
                     msg = E(f"インデックス{i}は不正な値です", v, False)
                     raise etype(msg)
             else:
-                is_type = inspect.isclass(validator)
-                vtype = validator if is_type else type(validator)
+                vtype = validator if (is_type := inspect.isclass(validator)) else type(validator)
                 msg = E(f"インデックス{i}は{vtype.__name__}型である必要があります", v, False)
                 if type(v) is bool:
                     if vtype is not bool:
@@ -577,8 +558,7 @@ class VTuple(VContainer):
                     msg = E(f"インデックス{i}は不正な値です", v, False)
                     raise etype(msg)
             else:
-                is_type = inspect.isclass(validator)
-                vtype = validator if is_type else type(validator)
+                vtype = validator if (is_type := inspect.isclass(validator)) else type(validator)
                 msg = E(f"インデックス{i}は{vtype.__name__}型である必要があります", v, False)
                 if type(v) is bool:
                     if vtype is not bool:
